# AirStuff

This small utility helps the poor guys who need to import publications into the AIR (Archivio Istituzionale della Ricerca). By default the program points to the UniMI database https://air.unimi.it/

It automatizes the extraction of: title, full authors list, list of authors for a given institution (see -h), keyword from the address of the inspirehep web page.

## Usage

    python inspire.py

![screenshot](https://raw.githubusercontent.com/wiso/AirStuff/master/screenshot.png)
